about summary refs log tree commit homepage
path: root/ext/kgio/accept.c
diff options
context:
space:
mode:
Diffstat (limited to 'ext/kgio/accept.c')
-rw-r--r--ext/kgio/accept.c20
1 files changed, 16 insertions, 4 deletions
diff --git a/ext/kgio/accept.c b/ext/kgio/accept.c
index 1a125ca..f14c791 100644
--- a/ext/kgio/accept.c
+++ b/ext/kgio/accept.c
@@ -283,8 +283,8 @@ static VALUE addr_bang(VALUE io)
  * value of +Kgio.accept_cloexec+ and +Kgio.accept_nonblock+.  +flags+
  * is a bitmask that may contain any combination of:
  *
* - Fcntl::FD_CLOEXEC - close-on-exec flag
* - IO::NONBLOCK - non-blocking flag
  */
 static VALUE tcp_tryaccept(int argc, VALUE *argv, VALUE self)
 {
@@ -320,8 +320,8 @@ static VALUE tcp_tryaccept(int argc, VALUE *argv, VALUE self)
  * value of +Kgio.accept_cloexec+ and +Kgio.accept_nonblock+.  +flags+
  * is a bitmask that may contain any combination of:
  *
* - Fcntl::FD_CLOEXEC - close-on-exec flag
* - IO::NONBLOCK - non-blocking flag
  */
 static VALUE tcp_accept(int argc, VALUE *argv, VALUE self)
 {
@@ -496,6 +496,18 @@ void init_kgio_accept(void)
         VALUE cUNIXServer, cTCPServer;
         VALUE mKgio = rb_define_module("Kgio");
 
+        /*
+         * this maps to the SOCK_NONBLOCK constant in Linux for setting
+         * the non-blocking flag on newly accepted sockets.
+         */
+        rb_define_const(mKgio, "SOCK_NONBLOCK", INT2NUM(SOCK_NONBLOCK));
+
+        /*
+         * this maps to the SOCK_CLOEXEC constant in Linux for setting
+         * the close-on-exec flag on newly accepted descriptors.
+         */
+        rb_define_const(mKgio, "SOCK_CLOEXEC", INT2NUM(SOCK_CLOEXEC));
+
         localhost = rb_const_get(mKgio, rb_intern("LOCALHOST"));
         cKgio_Socket = rb_const_get(mKgio, rb_intern("Socket"));
         cClientSocket = cKgio_Socket;
@@ -283,8 +283,8 @@ static VALUE addr_bang(VALUE io)
  * is a bitmask that may contain any combination of:
  *
- * - Fcntl::FD_CLOEXEC - close-on-exec flag
- * - IO::NONBLOCK - non-blocking flag
+ * - Kgio::SOCK_CLOEXEC - close-on-exec flag
+ * - Kgio::SOCK_NONBLOCK - non-blocking flag
  */
 static VALUE tcp_tryaccept(int argc, VALUE *argv, VALUE self)
@@ -320,8 +320,8 @@ static VALUE tcp_tryaccept(int argc, VALUE *argv, VALUE self)
  * is a bitmask that may contain any combination of:
  *
- * - Fcntl::FD_CLOEXEC - close-on-exec flag
- * - IO::NONBLOCK - non-blocking flag
+ * - Kgio::SOCK_CLOEXEC - close-on-exec flag
+ * - Kgio::SOCK_NONBLOCK - non-blocking flag
  */
 static VALUE tcp_accept(int argc, VALUE *argv, VALUE self)